@@ -6,7 +6,6 @@ class AttrDictVars:
     """Common base class for accessing variables as attributes or dict."""
 
     _type_hints_cache: Dict[str, Dict[str, Any]] = {}
-    _external_name_prefix = ""
 
     @classmethod
     def _get_type_hints(cls) -> Dict[str, Any]:
@@ -17,3 +16,6 @@ class AttrDictVars:
 
     def _attr_to_var_name(self, name: str) -> str:
         return name.replace("_", "-")
+
+    def _external_name(self, name: str) -> str:
+        return name
